import type { ColorToken } from '@loadsmart/miranda-tokens';
import { Component } from '../component';
import '../layout';
import '../icon';
export interface CardProps {
    flagged?: boolean;
    flagColor?: ColorToken;
    collapsible?: boolean;
    collapsed?: boolean;
    initialCollapsed?: boolean;
}
export interface CardToggleEventDetails {
    name: 'card';
    value: boolean;
}
export declare class Card extends Component implements CardProps {
    #private;
    static styles: import("lit").CSSResult[];
    static get properties(): {
        flagged: {
            type: BooleanConstructor;
        };
        flagColor: {
            type: StringConstructor;
            attribute: string;
        };
        collapsible: {
            type: BooleanConstructor;
        };
        collapsed: {
            type: BooleanConstructor;
            reflect: boolean;
        };
        initialCollapsed: {
            type: BooleanConstructor;
            attribute: string;
        };
    };
    /**
     * Should the card be flagged.
     */
    flagged: CardProps['flagged'];
    /**
     * Card flag color.
     */
    flagColor: NonNullable<CardProps['flagColor']>;
    /**
     * Should card be collapsible.
     */
    collapsible: CardProps['collapsible'];
    /**
     * Should card be collapsed.
     */
    collapsed: CardProps['collapsed'];
    /**
     * Initial collapsed state. used when collapsed is uncontrollable.
     */
    initialCollapsed: boolean;
    static define(): void;
    constructor();
    /**
     * Keeping the method name to avoid breaking changes.
     * #toggle was added to keep the pattern used in all
     * the other components, with the same behavior.
     */
    toggleCollapse(): void;
    isExpanded(): "true" | "false" | undefined;
    firstUpdated(): void;
    render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'm-card': Card;
    }
}
