export declare const DRAWER_SIZES: readonly ["small", "medium", "large"];
export type DrawerSize = (typeof DRAWER_SIZES)[number];
export interface DrawerProps {
    /**
     * Determine if the dialog is open or closed
     */
    open?: boolean;
    /**
     * Determines the size of the dialog
     */
    size?: DrawerSize;
    /**
     * Determines if the header and actions should have a divider and the body should have the secondary background.
     */
    divided?: boolean;
    /**
     * Event handler for closing the drawer.
     * we cannot expose this one because it clashes with the global 'close' event.
     *
     * Leaving this here for awareness.
     */
    /**
     * Event handler for when the drawer is opening.
     */
    onopening?: (event: CustomEvent) => void;
    /**
     * Event handler for when the drawer has just been opened.
     */
    onopened?: (event: CustomEvent) => void;
    /**
     * Event handler for when the drawer is closing.
     */
    onclosing?: (event: CustomEvent) => void;
    /**
     * Event handler for when the drawer has just been closed.
     */
    onclosed?: (event: CustomEvent) => void;
}
