import type { PropertyValues } from 'lit';
import { Component } from '../component';
import type { PopoverProps } from './popover.types';
export declare const POPOVER_PLACEMENT_VALUES: string[];
export declare class Popover extends Component {
    #private;
    static get properties(): {
        position: {
            type: StringConstructor;
            reflect: boolean;
        };
        placement: {
            type: StringConstructor;
        };
        open: {
            type: BooleanConstructor;
            reflect: boolean;
        };
        asPopover: {
            type: BooleanConstructor;
            attribute: string;
        };
    };
    /**
     * Popover positioning strategy.
     */
    position: PopoverProps['position'];
    /**
     * Popover placement.
     */
    placement: PopoverProps['placement'];
    /**
     * Should popover's floating be open.
     */
    open: PopoverProps['open'];
    /**
     * Should use native Popover API to render the floating element.
     * @see {@link https://developer.mozilla.org/en-US/docs/Web/API/Popover_API|Popover API}
     */
    asPopover: PopoverProps['asPopover'];
    constructor();
    disconnectedCallback(): void;
    protected firstUpdated(): void;
    updated(changedProperties: PropertyValues<this>): void;
    getReferenceElement(): HTMLElement | null;
    getFloatingElement(): HTMLElement | null;
    getArrowElement(): HTMLElement | null;
    getFloatingOffset: () => number;
    get reference(): HTMLElement | null;
    get floating(): HTMLElement | null;
    get arrow(): HTMLElement | null;
    show(): void;
    hide(): void;
    toggle(): void;
    renderArrow: () => import("lit-html").TemplateResult<1>;
    reposition: (reason?: string) => Promise<void>;
}
