import type { LitElement } from 'lit';
import type { StaticValue } from 'lit/static-html.js';
import type { HTMLTag } from './polymorphic-tag.types';
import type { Constructor } from '../../utils/types';
import { HTML_TAGS } from './polymorphic-tag.constants';
/**
 * This mixin allows a component to render with different types of tags, based on the provided `allowedTags`.
 * Be aware that, this mixin does **NOT** change the type (TS-wise) of your component, so, for tags that have their specific
 * attributes (e.g., button, a), your component must accept and properly render those attributes.
 * This is just a convenience layer for rendering a dynamically provided tag.
 *
 * TL;DR; either limit the tags you will allow for component, or add the additional attributes to your component to
 * comply with the tags that will be supported.
 */
export declare const PolymorphicTagMixin: <T extends Constructor<LitElement>, AllowedTags extends Readonly<HTMLTag[]> = typeof HTML_TAGS>({ superClass, allowedTags, fallbackTag, }: {
    superClass: T;
    allowedTags?: AllowedTags;
    fallbackTag?: HTMLTag;
}) => Constructor<{
    as: (typeof allowedTags)[number];
    readonly tag: StaticValue;
}> & T;
